# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 0.x     | :white_check_mark: |

## Reporting a Vulnerability

Please report (suspected) security vulnerabilities to **dev@infuseai.io**. You will receive a response from us within 48 hours. In the response, we will confirm whether the vulnerability was indeed found, and we will discuss the steps towards a solution.

It's important to never publicly disclose a security vulnerability before it has been fully resolved, as this can potentially put the wider community at risk.

### Security Vulnerability Response

* Acknowledgement of receipt of the report
* Regular updates about the progress towards fixing the vulnerability
* An announced release date for the patch fixing the vulnerability

### Public Disclosure Timing

After the initial reply to your report, we will keep you informed of the progress towards a fix and full announcement. We aim to handle all security vulnerabilities in a timely manner. After the vulnerability has been fixed, we will publish a security advisory along with credit to the reporter if desired.

Thank you for helping to keep Recce and its users safe!
